@@ -4,8 +4,8 @@ Created on Fri Feb 19 16:48:23 2021
 
 @author: berni
 """
-from phylab.lab import (np, plt, grid, std_unc, prnpar, errcor, Ell_coords)
-from phylab import lab
+from phylab import (np, plt, grid, std_unc, prnpar, errcor, Ell_coords)
+import phylab as lab
 
 ''' Variables that control the script '''
 gen = False # generate measured points around circumference
@@ -49,7 +49,7 @@ else: unc = np.zeros_like(sol)
 
 if tex: plt.rc('text', usetex=True); plt.rc('font', family='serif')
 xCop, yCop = Ell_coords(*cen, rad); xfit, yfit = Ell_coords(*pars); xEl, yEl = Ell_coords(*p)
-fig, axs = plt.subplots(1,2, sharex=True); axc = axs[0]; axe = axs[1]
+fig, axs = plt.subplots(1, 2, sharex=True); axc = axs[0]; axe = axs[1]
 for ax in axs:
     grid(ax); ax.axis('equal')
     ax.errorbar(*data, dy, dx, 'ko', ms=1.2, elinewidth=0.8, capsize= 1.1,
@@ -61,7 +61,7 @@ axc.plot(cen[0], cen[1], c='c', marker='.', label='Coope center')
 axc.plot(xfit, yfit, c='y', ls='--', lw=0.8, zorder=10, alpha=0.6, label='circle fit radius')
 axc.errorbar(*pars[:-1], *perr[:-1],'yo', ms=1.5, elinewidth=0.9, capsize= 1.2,
         ls='', label='circle fit center')
-if con: 
+if con:
     axc.plot(*Ell_coords(*pars[:-1], a=pars[-1] + perr[-1]), c='r', ls='--', lw=0.8,
             zorder=10, alpha=0.6, label='circle fit $r + dr$')
     axc.plot(*Ell_coords(*pars[:-1], a=pars[-1] - perr[-1]), c='b', ls='--', lw=0.8,
@@ -71,7 +71,7 @@ if con:
 axe.plot(xEl, yEl, c='m', ls='--', lw=0.8, zorder=10, alpha=0.6, label='best-fit ellipse')
 axe.errorbar(p[0], p[1], unc[1], unc[0], 'mo', ms=1.5, elinewidth=0.9,
             capsize= 1.2, label='ellipse center')
-if gen: 
+if gen:
     axe.plot(*Ell_coords(*init, step=npts), c='pink', ls='-', lw=1,
                 zorder=10, alpha=0.6, label='generated ellipse')
     axe.plot(init[0], init[1], c='pink', marker='.', label='generated center')
@@ -85,7 +85,7 @@ for ax in axs: ax.legend(loc ='best')
 # Plot the Chi square surface for circle's center coordinates
 a_range = np.linspace(pars[0] - 10*perr[0], pars[0] + 10*perr[0], 50)
 b_range = np.linspace(pars[1] - 10*perr[1], pars[1] + 10*perr[1], 50)
-chi_ab = lab.chisq(x=data, y=rsq, model=circ_dist, alpha=a_range, beta=b_range,
+chi_ab = lab.chisq(model=circ_dist, x=data, y=rsq, alpha=a_range, beta=b_range,
                    varnames = ['Xc', 'Yc'], pars=pars, dy=None)
 
 fig3d, ax3d = lab.plot3d(x=a_range, y=b_range, z=chi_ab, xlab='$x_c$', ylab='$y_c$',
@@ -94,4 +94,4 @@ ax3d.set_zlim(0, None)
 if tex: ax3d.set_title(r'$\displaystyle \chi^2(x_c, y_c) = \sum_{i=1}^n'
                 r'\left(\frac{r_i^2 - (2x_c x_i + 2y_c y_i + R_c^2)}{\sigma_{r^2_i}}\right)^2$'
                 r'of circle fit $(x_i^2 + y_i^2 := r_i^2)$' , fontsize=12)
-plt.show()
\ No newline at end of file
+plt.show()
